/**
 * Copyright (c) 2017-present, Wonday (@wonday.org)
 * All rights reserved.
 *
 * This source code is licensed under the MIT-style license found in the
 * LICENSE file in the root directory of this source tree.
 */

package com.library;

import java.util.Collections;
import java.util.List;
import java.util.ArrayList;

import com.facebook.react.ReactPackage;
import com.facebook.react.bridge.JavaScriptModule;
import com.facebook.react.bridge.NativeModule;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.uimanager.ViewManager;
import com.library.pdf.graph.RCTGraphBoxManager;
import com.library.pdf.hr.RCTHrBoxManager;
import com.library.pdf.hr.RCTHrModule;
import com.library.pdf.pdfbox.RCTPdfBoxManager;
import com.library.pdf.pdf.RCTPdfManager;
import com.library.pdf.pdf.RCTPdfUtilityModule;
import com.library.pdf.png.RCTPngViewManager;

public class RCTPdfView implements ReactPackage {

    @Override
    public List<NativeModule> createNativeModules(ReactApplicationContext reactContext) {
        List<NativeModule> modules = new ArrayList<>();
        modules.add(new RCTPdfUtilityModule(reactContext));
        modules.add(new RCTHrModule(reactContext));
        return modules;
    }

    // Deprecated as of RN 0.47.0
    public List<Class<? extends JavaScriptModule>> createJSModules() {
        return Collections.emptyList();
    }

    @Override
    public List<ViewManager> createViewManagers(ReactApplicationContext reactContext) {
        List<ViewManager> modules = new ArrayList<>();
        modules.add(new RCTPdfManager(reactContext));
        modules.add(new RCTPdfBoxManager(reactContext));
        modules.add(new RCTGraphBoxManager(reactContext));
        modules.add(new RCTPngViewManager(reactContext));
        modules.add(new RCTHrBoxManager(reactContext));
        return modules;
    }
}
