package com.library.pdf.graph;

import android.content.Context;
import android.graphics.Bitmap;

import com.facebook.react.bridge.ReadableMap;
import com.library.pdf.Box;

public class GraphBox extends Box {
    private String path;
    private double pageWidth;
    private double pageHeight;
    private double top;
    private double left;
    private double boxWidth;
    private double boxHeight;
    private int index;
    private boolean visible;

    public GraphBox(Context context) {
        super(context);
    }

    public void setPageSize(ReadableMap pageSize) {
        this.pageWidth = pageSize.getDouble("width");
        this.pageHeight = pageSize.getDouble("height");
    }

    public void setCoordinates(ReadableMap coordinates) {
        ReadableMap origin = coordinates.getMap("origin");
        this.top = origin.getDouble("y");
        this.left = origin.getDouble("x");
        ReadableMap size = coordinates.getMap("size");
        this.boxWidth = size.getDouble("width");
        this.boxHeight = size.getDouble("height");
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getPath() {
        return path;
    }

    public double getPageWidth() {
        return pageWidth;
    }

    public double getPageHeight() {
        return pageHeight;
    }

    public double getOriginTop() {
        return top;
    }

    public double getOriginLeft() {
        return left;
    }

    public double getBoxWidth() {
        return boxWidth;
    }

    public double getBoxHeight() {
        return boxHeight;
    }

    public int getIndex() {
        return index;
    }

    public void setIndex(int index) {
        this.index = index;
    }

    public boolean isVisible() {
        return visible;
    }

    public void setVisible(boolean visible) {
        this.visible = visible;
    }

    @Override
    public Bitmap getBitmap(int scale) {
        return GraphManager.getInstance().getBitmap(this);
    }

    @Override
    public String toString() {
        return "PdfBox{" +
                "path='" + path + '\'' +
                ", pageWidth=" + pageWidth +
                ", pageHeight=" + pageHeight +
                ", top=" + top +
                ", left=" + left +
                ", boxWidth=" + boxWidth +
                ", boxHeight=" + boxHeight +
                ", skipEmpty='" + isSkipEmpty() + '\'' +
                '}';
    }
}
