package com.library.pdf.graph;

import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.util.Log;
import android.view.View;

import java.io.File;
import java.util.HashMap;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

import static com.facebook.react.bridge.UiThreadUtil.runOnUiThread;

import com.library.pdf.Utils;
public class GraphManager {
    private static GraphManager instance;
    private HashMap<String, Bitmap> graphBitmaps;
    private ExecutorService executors;

    private GraphManager(){
        executors = Executors.newFixedThreadPool(1);
        graphBitmaps = new HashMap<>();
    }

    public static GraphManager getInstance() {
        if (instance == null) {
            synchronized (GraphManager.class){
                if (instance == null) {
                    instance = new GraphManager();
                }
            }
        }
        return instance;
    }

    public Bitmap getGraphBitmap(String path){
        if(graphBitmaps.get(path) == null){
            File imgFile = new File(path);
            if (imgFile.exists()) {
                try {
                    graphBitmaps.put(path, BitmapFactory.decodeFile(imgFile.getAbsolutePath()));
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        }
        return graphBitmaps.get(path);
    }

    public Bitmap getBitmap(GraphBox view) {
        try{
            Bitmap graph = getGraphBitmap(view.getPath());
            return Bitmap.createBitmap(graph,
                    (int) view.getOriginLeft(),
                    (int) view.getOriginTop(),
                    (int) view.getBoxWidth(),
                    (int) view.getBoxHeight());
        }catch (Exception e){
            return null;
        }
    }

    void addToList(final GraphBox view){
        try {
            if (view.isVisible()) {
                view.setVisibility(View.VISIBLE);
                executors.submit(new Runnable() {
                    @Override
                    public void run() {
                        renderBox(view);
                    }
                });
            } else {
                view.setImageResource(0);
                view.setVisibility(View.GONE);
            }
        } catch (OutOfMemoryError ome){
            ome.printStackTrace();
        }
    }

    private void cropBitmap(final GraphBox view){
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                Bitmap bitmap = getBitmap(view);
                if(!view.isSkipEmpty() || !Utils.isEmpty(bitmap)) {
                    view.setImageBitmap(bitmap);
                } else {
                    bitmap.recycle();
                    Log.d("GRAPH_MANAGER_BOX", "skip " + view);
                }
            }
        });
    }

    private void renderBox(GraphBox view){
        try {
            Log.d("GRAPH_MANAGER_BOX", view.toString());
            cropBitmap(view);
        } catch (Exception e){
            e.printStackTrace();
        }
    }
}
