package com.library.pdf.hr;

import androidx.annotation.Nullable;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableArray;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.SimpleViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.uimanager.events.RCTEventEmitter;

import java.util.Map;

public class RCTHrBoxManager extends SimpleViewManager<HrBox> {
    private static final String REACT_CLASS = "RCTHrBox";

    private static final int INVALIDATE_BOX = 0;

    private final HrManager mgrInstance;
    private ReactApplicationContext reactContext;

    public RCTHrBoxManager(ReactApplicationContext reactContext){
        mgrInstance = HrManager.getInstance();
        this.reactContext = reactContext;
    }

    @Override
    public String getName() {
        return REACT_CLASS;
    }

    @Override
    public HrBox createViewInstance(ThemedReactContext context) {
        HrBox box = new HrBox(context);
        box.setListener(new OnDownloadListener() {
            @Override
            public void onDownloaded(HrBox view) {
                dispatchEvent(view, HrManager.EVENT_HR_DOWNLOADED);
            }

            @Override
            public void onError(HrBox view, Throwable t) {
                dispatchEvent(view, HrManager.EVENT_HR_ERROR, t);
            }

            @Override
            public void onLoadEnd(HrBox view) {
                dispatchEvent(view, HrManager.EVENT_HR_LOADED);
            }
        });
        return box;
    }

    @Override
    public void onDropViewInstance(HrBox box) {
        box = null;
    }

    @ReactProp(name = "name")
    public void setName(HrBox box, String name) {
        box.setName(name);
    }

    @ReactProp(name = "index")
    public void setIndex(HrBox box, int index) {
        box.setIndex(index);
    }

    @ReactProp(name="url")
    public void setUrl(HrBox box, String url){
        box.setUrl(url);
    }

    @ReactProp(name = "path")
    public void setPath(HrBox box, String path) {
        box.setPath(path);
    }

    @ReactProp(name = "zipPath")
    public void setZipPath(HrBox box, String path) {
        box.setZipPath(path);
    }

    @ReactProp(name = "visible")
    public void setVisible(HrBox box, boolean visible){
        box.setVisible(visible);
    }

    @ReactProp(name = "skipEmpty")
    public void setSkipEmpty(HrBox box, boolean skipEmpty){
        box.setSkipEmpty(skipEmpty);
    }
    @ReactProp(name = "graph")
    public void setGraph(HrBox box, boolean graph){
        box.setGraph(graph);
    }

    @Override
    public void onAfterUpdateTransaction(HrBox box) {
        super.onAfterUpdateTransaction(box);
        box.setRetry(0);
        mgrInstance.addToList(box);
    }

    @Override
    public void receiveCommand(HrBox box, int commandId, @Nullable ReadableArray args) {
        super.receiveCommand(box, commandId, args);
        if (commandId == INVALIDATE_BOX) {
            box.setRetry(0);
            box.setInvalidate(true);
            mgrInstance.addToList(box);
        }
    }

    public void dispatchEvent(HrBox box, String eventName, Throwable t) {
        WritableMap map = Arguments.createMap();
        map.putString("message", t.getMessage());
        reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(box.getId(), eventName, map);
    }

    public void dispatchEvent(HrBox box, String eventName) {
        reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(box.getId(), eventName, Arguments.createMap());
    }

    @Override
    public @Nullable Map<String, Object> getExportedCustomDirectEventTypeConstants() {
        return MapBuilder.<String, Object>builder()
                .put(HrManager.EVENT_HR_DOWNLOADED, MapBuilder.of("registrationName", "onHrDownloaded"))
                .put(HrManager.EVENT_HR_LOADED, MapBuilder.of("registrationName", "onHrLoaded"))
                .put(HrManager.EVENT_HR_ERROR, MapBuilder.of("registrationName", "onHrError"))
                .build();
    }
}
