package com.library.pdf.hr;

import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.TimeUnit;

/**
 * A thin wrapper around a thread pool executor that only exposes partially what the executor is
 * doing. This is so that we don't make a mistake somewhere along the way and jack something up.
 *
 * @author Matthew A. Johnston (warmwaffles)
 */
public class Scheduler {
    private static final int CORE_POOL_SIZE = 2;
    private static final int MAX_POOL_SIZE = 4;

    private PausableThreadPoolExecutor executor;
    private LinkedBlockingQueue<Runnable> queue;

    public Scheduler() {
        queue = new LinkedBlockingQueue<Runnable>();
        executor = new PausableThreadPoolExecutor(CORE_POOL_SIZE, MAX_POOL_SIZE, 1, TimeUnit.SECONDS, queue);
    }

    public void schedule(Runnable runnable) throws OutOfMemoryError {
        if(executor != null) {
            executor.execute(runnable);
        }
    }

    public void pause() {
        if(executor != null) {
            executor.pause();
        }
    }

    public void resume() {
        if(executor != null) {
            executor.resume();
        }
    }

    public void clear() {
        if(queue != null) {
            queue.clear();
        }
    }

    public void setPoolSize(int size){
        if(executor != null){
            try{
                executor.setCorePoolSize(Math.min(Math.max(size, 0), CORE_POOL_SIZE));
                executor.setMaximumPoolSize(Math.min(Math.max(size, 0), MAX_POOL_SIZE));
            } catch (IllegalArgumentException e){
                e.printStackTrace();
            }
        }
    }

    public boolean isEmpty() {
        if(queue != null) {
            return queue.isEmpty();
        }
        return true;
    }
}
