package com.library.pdf.pdf;

import java.io.File;

import android.graphics.Rect;
import android.net.Uri;
import android.util.AttributeSet;
import android.graphics.Canvas;
import android.util.DisplayMetrics;
import android.util.Log;
import android.util.TypedValue;

import com.facebook.react.uimanager.events.RCTEventEmitter;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.WritableMap;
import com.facebook.react.uimanager.ThemedReactContext;
import com.library.viewer.PDFView;
import com.library.viewer.listener.OnDrawListener;
import com.library.viewer.listener.OnErrorListener;
import com.library.viewer.listener.OnLoadCompleteListener;
import com.library.viewer.util.FitPolicy;

public class PdfView extends PDFView implements OnLoadCompleteListener, OnErrorListener, OnDrawListener {
    private ThemedReactContext context;
    private String path;
    private String assetName;
    private FitPolicy fitPolicy = FitPolicy.HEIGHT;
    private float offsetX = 0;
    private float offsetY = 0;
    private float visibleWidth = 0;
    private float visibleHeight = 0;

    public PdfView(ThemedReactContext context, AttributeSet set) {
        super(context, set);
        this.context = context;
    }

    @Override
    public void loadComplete(int numberOfPages) {
        context.getJSModule(RCTEventEmitter.class).receiveEvent(getId(), "onPdfLoaded", null);
    }

    @Override
    public void onError(Throwable t) {
        WritableMap params = Arguments.createMap();
        params.putString("message", t.getMessage());
        context.getJSModule(RCTEventEmitter.class).receiveEvent(getId(), "onPdfError", params);
    }

    @Override
    public void onLayerDrawn(Canvas canvas, float pageWidth, float pageHeight, int displayedPage) {
        context.getJSModule(RCTEventEmitter.class).receiveEvent(getId(), "onPdfDrawn", null);
    }

    private Rect getVisibleRectByReact(){
        DisplayMetrics dm = getContext().getResources().getDisplayMetrics();
        float leftDip = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, offsetX, dm);
        float topDip = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, offsetY, dm);
        float widthDip = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, visibleWidth, dm);
        float heightDip = TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, visibleHeight, dm);
        Rect visible = new Rect();
        visible.left = (int) (leftDip * getScale());
        visible.top = (int) (topDip * getScale());
        visible.right = (int) ((leftDip + widthDip) * getScale());
        visible.bottom = (int) ((topDip + heightDip )* getScale());

        return visible;
    }

    public void drawPdf() {
        if (this.path != null || this.assetName != null) {
            Rect newVisibleRect = getVisibleRectByReact();//new Rect();
            //getLocalVisibleRect(newVisibleRect);
            Rect loadedRect = getPagesLoader().getLoaded();
            Log.d("PDF_VIEW", "state: " + this.state);
            Log.d("PDF_VIEW", "visible rect: " + newVisibleRect);
            Log.d("PDF_VIEW", "loaded rect: " + loadedRect);
            if (this.state == State.DEFAULT || loadedRect == null) {
                Log.d("PDF_VIEW", "init pdf view");
                getPagesLoader().setLoaded(newVisibleRect);
                this.useBestQuality(true);
                Configurator configurator;
                if(assetName != null){
                    configurator = fromAsset(assetName);
                } else {
                    configurator = fromUri(getURI(this.path));
                }

                configurator.onLoad(this).onError(this).onDraw(this).spacing(0)
                        .enableAntialiasing(true).enableAnnotationRendering(true).pageFitPolicy(this.fitPolicy)
                        .autoSpacing(false).swipeHorizontal(true).load();
            } else if (getScale() != getPagesLoader().getLoadedScale()) {
                Log.d("PDF_VIEW", "update");
                getPagesLoader().setLoaded(newVisibleRect);
                this.loadPages();
            } else if(!loadedRect.contains(newVisibleRect)){
                Log.d("PDF_VIEW", "update");
                getPagesLoader().setLoaded(newVisibleRect);
                this.loadPages();
            }
        }
    }

    public void setPath(String path) {
        this.path = path;
    }

    public void setOffsetX(float offset) {
        this.offsetX = offset;
    }

    public void setOffsetY(float offset) {
        this.offsetY = offset;
    }

    private Uri getURI(final String uri) {
        Uri parsed = Uri.parse(uri);

        if (parsed.getScheme() == null || parsed.getScheme().isEmpty()) {
            return Uri.fromFile(new File(uri));
        }
        return parsed;
    }

    public void setVisibleWidth(float width) {
        this.visibleWidth = width;
    }

    public void setVisibleHeight(float height) {
        this.visibleHeight = height;
    }

    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
}
