package com.library.pdf.pdfbox;

import android.content.Context;
import android.graphics.Bitmap;

import androidx.annotation.Nullable;

import com.facebook.react.bridge.ReadableMap;
import com.library.pdf.Box;

import static com.facebook.react.bridge.UiThreadUtil.runOnUiThread;

public class PdfBox extends Box {
    private String path;
    private float scale;
    private double pageWidth;
    private double pageHeight;
    private double top;
    private double left;
    private double boxWidth;
    private double boxHeight;
    private int artId;
    private int pageId;
    private Bitmap bitmap;
    private boolean visible;

    public PdfBox(Context context) {
        super(context);
    }

    public void setPageSize(ReadableMap pageSize) {
        this.pageWidth = pageSize.getDouble("width");
        this.pageHeight = pageSize.getDouble("height");
    }

    public void setCoordinates(ReadableMap coordinates) {
        ReadableMap origin = coordinates.getMap("origin");
        this.top = origin.getDouble("y");
        this.left = origin.getDouble("x");
        ReadableMap size = coordinates.getMap("size");
        this.boxWidth = size.getDouble("width");
        this.boxHeight = size.getDouble("height");
    }

    public void setPageWidth(double pageWidth) {
        this.pageWidth = pageWidth;
    }

    public void setPageHeight(double pageHeight) {
        this.pageHeight = pageHeight;
    }

    public void setOrigY(double top) {
        this.top = top;
    }

    public void setOrigX(double left) {
        this.left = left;
    }

    public void setBoxWidth(double boxWidth) {
        this.boxWidth = boxWidth;
    }

    public void setBoxHeight(double boxHeight) {
        this.boxHeight = boxHeight;
    }

    public void setScale(float scale) {
        this.scale = Math.max(scale, 1);
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getPath() {
        return path;
    }

    public float getScale() {
        return scale;
    }

    public double getPageWidth() {
        return pageWidth;
    }

    public double getPageHeight() {
        return pageHeight;
    }

    public double getOriginTop() {
        return top;
    }

    public double getOriginLeft() {
        return left;
    }

    public double getBoxWidth() {
        return boxWidth;
    }

    public double getBoxHeight() {
        return boxHeight;
    }

    public void setArtId(int artId) {
        this.artId = artId;
    }

    public void setPageId(int pageId) {
        this.pageId = pageId;
    }

    public String getKey(){
        return scale + "_" + pageId + "_" + artId;
    }

    @Override
    public String toString() {
        return "PdfBox{" +
                "path='" + path + '\'' +
                ", scale=" + scale +
                ", pageWidth=" + pageWidth +
                ", pageHeight=" + pageHeight +
                ", top=" + top +
                ", left=" + left +
                ", boxWidth=" + boxWidth +
                ", boxHeight=" + boxHeight +
                ", artId=" + artId +
                ", pageId=" + pageId +
                ", skipEmpty='" + isSkipEmpty() + '\'' +
                '}';
    }

    @Override
    public boolean equals(@Nullable Object obj) {
        if(obj instanceof PdfBox){
            return this.getKey().equals(((PdfBox) obj).getKey());
        }
        return false;
    }


    public void setBitmap(final Bitmap bmp) {
        runOnUiThread(new Runnable() {
            @Override
            public void run() {
                setImageBitmap(bmp);
            }
        });
    }

    @Override
    public Bitmap getBitmap(int scale) {
        return PDFiumManager.getInstance(getContext()).getBitmap(this, scale);
    }

    public void setVisible(boolean visible) {
        this.visible = visible;
    }

    public boolean isVisible() {
        return visible;
    }
}
