package com.library.pdf.pdfbox;

import android.content.Context;
import android.util.Log;

import androidx.annotation.Nullable;

import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.ReadableMap;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.SimpleViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.annotations.ReactProp;

import java.util.Map;

public class RCTPdfBoxManager extends SimpleViewManager<PdfBox> {
    private static final String REACT_CLASS = "RCTPdfBox";
    private final PDFiumManager mgrInstance;
    private Context context;
    private PdfBox pdfBox;

    public RCTPdfBoxManager(ReactApplicationContext reactContext){
        this.context = reactContext;
        mgrInstance = PDFiumManager.getInstance(context);
    }

    @Override
    public String getName() {
        return REACT_CLASS;
    }

    @Override
    public PdfBox createViewInstance(ThemedReactContext context) {
        this.pdfBox = new PdfBox(context);
        return pdfBox;
    }

    @Override
    public void onDropViewInstance(PdfBox pdfBox) {
        pdfBox = null;
    }

    @ReactProp(name = "path")
    public void setPath(PdfBox pdfBox, String path) {
        pdfBox.setPath(path);
    }

    @ReactProp(name = "coordinates")
    public void setCoordinates(PdfBox pdfBox, ReadableMap coordinates){
        pdfBox.setCoordinates(coordinates);
    }

    @ReactProp(name = "pageSize")
    public void setPageSize(PdfBox pdfBox, ReadableMap pageSize){
        pdfBox.setPageSize(pageSize);
    }

    @ReactProp(name = "scale")
    public void setScale(PdfBox pdfBox, float scale) {
        pdfBox.setScale(scale);
    }

    @ReactProp(name = "pageId")
    public void setPageId(PdfBox pdfBox, int pageId){
        Log.d(REACT_CLASS, "set page id: " + pageId);
        pdfBox.setPageId(pageId);
    }

    @ReactProp(name = "artId")
    public void setArtId(PdfBox pdfBox, int artId){
        Log.d(REACT_CLASS, "set art id: " + artId);
        pdfBox.setArtId(artId);
    }

    @ReactProp(name = "visible")
    public void setVisible(PdfBox pdfBox, boolean visible){
        pdfBox.setVisible(visible);
    }

    @ReactProp(name = "skipEmpty")
    public void setSkipEmpty(PdfBox box, boolean skipEmpty){
        box.setSkipEmpty(skipEmpty);
    }
    @Override
    public void onAfterUpdateTransaction(PdfBox pdfBox) {
        super.onAfterUpdateTransaction(pdfBox);
        mgrInstance.addToList(pdfBox);
    }

    @Override
    public @Nullable Map<String, Object> getExportedCustomDirectEventTypeConstants() {
        return MapBuilder.<String, Object>builder()
                .put("onBoxDrawn", MapBuilder.of("registrationName", "onBoxDrawn"))
                .put("onPdfError", MapBuilder.of("registrationName", "onPdfError"))
                .build();
    }
}
