package com.library.pdf.png;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.PaintFlagsDrawFilter;
import android.graphics.Rect;
import android.graphics.drawable.Drawable;
import android.util.AttributeSet;
import android.widget.RelativeLayout;

import java.io.File;

public class PngView extends RelativeLayout {
    private static final int IN_SAMPLE_SIZE_MAX = 10;
    /** Paint object for drawing */
    private Paint paint;
    private PaintFlagsDrawFilter antialiasFilter = new PaintFlagsDrawFilter(0, Paint.ANTI_ALIAS_FLAG | Paint.FILTER_BITMAP_FLAG);
    private Bitmap background;
    private File path;
    private boolean running = false;

    public PngView(Context context, AttributeSet set) {
        super(context, set);
        paint = new Paint();
    }

    @Override
    protected void onDraw(Canvas canvas) {
        super.onDraw(canvas);

        Drawable bg = getBackground();
        if (bg == null) {
            canvas.drawColor(Color.TRANSPARENT);
        }
        canvas.setDrawFilter(antialiasFilter);

        if(background == null || background.isRecycled()){
            readBitmap(1);
        } else {
            drawBitmap(canvas, background);
        }
    }

    private void drawBitmap(Canvas canvas, Bitmap bitmap){
        Rect srcRect = new Rect(0, 0, bitmap.getWidth(), bitmap.getHeight());
        Rect dstRect = new Rect(0, 0, getWidth(), getHeight());
        canvas.drawBitmap(bitmap, srcRect, dstRect, paint);
    }

    private synchronized void readBitmap(final int inSampleSize){
        if(path != null && path.exists() && !running && inSampleSize < IN_SAMPLE_SIZE_MAX) {
            running = true;
            post(new Runnable() {
                @Override
                public void run() {
                    try {
                        BitmapFactory.Options options = new BitmapFactory.Options();
                        options.inSampleSize = inSampleSize;
                        background = BitmapFactory.decodeFile(path.getPath());
                        if (background != null) {
                            invalidate();
                        }
                        running = false;
                    } catch (OutOfMemoryError ome){
                        running = false;
                        System.gc();
                        readBitmap(inSampleSize + 2);
                    }
                }
            });
        }
    }

    public File getPath() {
        return path;
    }

    public void setPath(File path) {
        this.path = path;
    }
}
