package com.library.pdf.png;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.common.MapBuilder;
import com.facebook.react.uimanager.SimpleViewManager;
import com.facebook.react.uimanager.ThemedReactContext;
import com.facebook.react.uimanager.annotations.ReactProp;
import com.facebook.react.uimanager.events.RCTEventEmitter;

import java.io.File;
import java.util.Map;

public class RCTPngViewManager extends SimpleViewManager<PngView> {
    private static final String REACT_CLASS = "RCTPngView";
    private final ReactApplicationContext reactContext;

    @NonNull
    @Override
    public String getName() {
        return REACT_CLASS;
    }

    public RCTPngViewManager(ReactApplicationContext reactContext) {
        this.reactContext = reactContext;
    }

    @NonNull
    @Override
    protected PngView createViewInstance(@NonNull ThemedReactContext reactContext) {
        return new PngView(reactContext, null);
    }

    @ReactProp(name = "path")
    public void setPath(PngView view, String path) {
        try {
            File image = new File(path);
            if(image.exists()){
                view.setPath(image);
            } else {
                reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(view.getId(), "onImageError", Arguments.createMap());
            }
        } catch ( Exception e ){
            reactContext.getJSModule(RCTEventEmitter.class).receiveEvent(view.getId(), "onImageError", Arguments.createMap());
        }

    }

    @Override
    public @Nullable
    Map<String, Object> getExportedCustomDirectEventTypeConstants() {
        return MapBuilder.<String, Object>builder()
                .put("onImageError", MapBuilder.of("registrationName", "onImageError"))
                .build();
    }
}
