/*
 * Copyright (C) 2016 Bartosz Schiller.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.library.viewer.util;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.ColorMatrix;
import android.graphics.ColorMatrixColorFilter;
import android.graphics.Matrix;
import android.graphics.Paint;
import android.graphics.PorterDuff;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.util.TypedValue;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;

public class Util {
    public static int getDP(Context context, int dp) {
        return (int) TypedValue.applyDimension(TypedValue.COMPLEX_UNIT_DIP, dp, context.getResources().getDisplayMetrics());
    }

    /**
     * merge thumbnail bitmap with a transparent rect with PorterDuff.Mode.CLEAR
     * this allow to display a low res text around high res pdf text and doesn't see white area
     * during pdf box loading
     */
    public static Bitmap mergeBitmaps(Bitmap back, Rect toClear, int attempt) {
        if (attempt == 2) {
            return null;
        }
        if (back != null && toClear != null && toClear.width() > 0 && toClear.height() > 0) {
            try {
                Bitmap clearBitmap = Bitmap.createBitmap(toClear.width(), toClear.height(), Bitmap.Config.ARGB_8888);
                if (clearBitmap != null) {
                    Bitmap result = Bitmap.createBitmap(back.getWidth(), back.getHeight(), back.getConfig());
                    Canvas canvas = new Canvas(result);
                    canvas.drawBitmap(back, 0f, 0f, null);
                    Paint clearPaint = new Paint();
                    clearPaint.setXfermode(new PorterDuffXfermode(PorterDuff.Mode.CLEAR));
                    canvas.drawBitmap(clearBitmap, toClear.left, toClear.top, clearPaint);
                    return result;
                }
            } catch (OutOfMemoryError e) {
                e.printStackTrace();
                System.gc();
                return mergeBitmaps(back, toClear, attempt + 1);
            }
        }
        return back;
    }
}
