function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
import React from "react";
import PropTypes from "prop-types";
import { requireNativeComponent, Platform, ViewPropTypes } from "react-native";
import { JSUtils } from "@tecnavia/react-native-utils";
let PdfComponent;
export default class Pdf extends React.Component {
  static propTypes = {
    ...ViewPropTypes,
    thumbnailRatio: PropTypes.number,
    size: PropTypes.shape({
      width: PropTypes.number,
      height: PropTypes.number
    }),
    visibleArea: PropTypes.shape({
      width: PropTypes.number,
      height: PropTypes.number,
      top: PropTypes.number,
      left: PropTypes.number
    }),
    path: PropTypes.string,
    asset: PropTypes.string,
    page: PropTypes.number,
    zoom: PropTypes.number,
    onLayout: PropTypes.bool,
    isDoubleTruck: PropTypes.bool,
    blackAndWhite: PropTypes.bool,
    onPdfDrawn: PropTypes.func,
    onPdfError: PropTypes.func,
    onPdfLoaded: PropTypes.func,
    enableThumbnail: PropTypes.bool
  };
  static defaultProps = {
    zoom: 1,
    page: 0,
    thumbnailRatio: 1,
    blackAndWhite: false,
    enableThumbnail: false
  };
  constructor(props) {
    super(props);
    this.pdfComponentName = Platform.select({
      android: "RCTPdf",
      ios: "RCTPdfView"
    });
    if (!PdfComponent) {
      PdfComponent = requireNativeComponent(this.pdfComponentName, Pdf, {
        nativeOnly: {
          path: true,
          onChange: true
        }
      });
    }
    this.onPdfLoaded = this._onPdfLoaded.bind(this);
    this.onPdfError = this._onPdfError.bind(this);
    this.onPdfDrawn = this._onPdfDrawn.bind(this);
  }
  shouldComponentUpdate(nextProps) {
    const {
      zoom,
      size,
      visibleArea
    } = this.props;
    if (nextProps.zoom !== zoom) {
      return true;
    }
    if (!JSUtils.areEqualShallow(nextProps.size, size)) {
      return true;
    }
    if (!JSUtils.areEqualShallow(nextProps.visibleArea, visibleArea)) {
      return true;
    }
    return false;
  }
  _onPdfLoaded() {
    const {
      onPdfLoaded
    } = this.props;
    if (typeof onPdfLoaded === "function") {
      onPdfLoaded();
    }
  }
  _onPdfError() {
    const {
      onPdfError
    } = this.props;
    if (typeof onPdfError === "function") {
      onPdfError();
    }
  }
  _onPdfDrawn() {
    const {
      onPdfDrawn
    } = this.props;
    if (typeof onPdfDrawn === "function") {
      onPdfDrawn();
    }
  }
  render() {
    const {
      onPdfLoaded,
      onPdfError,
      onPdfDrawn,
      visibleArea,
      zoom: scale,
      ...rest
    } = this.props;
    return /*#__PURE__*/React.createElement(PdfComponent, _extends({
      ref: component => {
        this._root = component;
      }
    }, rest, {
      scale: scale,
      offsetX: visibleArea.left || 0,
      offsetY: visibleArea.top || 0,
      visibleWidth: visibleArea.width || 0,
      visibleHeight: visibleArea.height || 0,
      onPdfLoaded: this.onPdfLoaded,
      onPdfError: this.onPdfError,
      onPdfDrawn: this.onPdfDrawn
    }));
  }
}
//# sourceMappingURL=pdf-component.js.map